==> ejc-proequipmentcorp-impl-3.0.0-20221020.151200-42-sources.jar: com/ejianc/business/proequipmentcorppur/purchase/bean/ChangePurchaseContractOtherDetailedEntity.java <==
package com.ejianc.business.proequipmentcorppur.purchase.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设备采购合同-变更表-其他费用明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_purchase_change_other_detailed")
public class ChangePurchaseContractOtherDetailedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="tree_index")
    private String treeIndex; // 序号
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 费用项
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="tax_price")
    private BigDecimal taxPrice; // 含税单价
    @TableField(value="num")
    private Integer num; // 数量
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="amount")
    private BigDecimal amount; // 金额
    @TableField(value="not_tax_price")
    private BigDecimal notTaxPrice; // 单价(无税)
    @TableField(value="not_tax_amount")
    private BigDecimal notTaxAmount; // 金额(无税)
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 税额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="change_id")
    private Long changeId; // 变更id
    @TableField(value="src_tbl_id")
    private Long srcTblId; // 来源子表主键
    @TableField(value="before_change_num")
    private BigDecimal beforeChangeNum;// 变更前数量
    @TableField(value="before_change_price")
    private BigDecimal beforeChangePrice;// 变更前单价(无税)
    @TableField(value="before_change_rate")
    private BigDecimal beforeChangeRate;// 变更前税率
    @TableField(value="change_type")
    private String changeType;// 变更类型
    @TableField(value="contrast_flag")
    private Boolean contrastFlag; // 是否合同带入单据

    public Boolean getContrastFlag() {
        return contrastFlag;
    }

    public void setContrastFlag(Boolean contrastFlag) {
        this.contrastFlag = contrastFlag;
    }

    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    public BigDecimal getNotTaxPrice() {
        return notTaxPrice;
    }

    public void setNotTaxPrice(BigDecimal notTaxPrice) {
        this.notTaxPrice = notTaxPrice;
    }
    public BigDecimal getNotTaxAmount() {
        return notTaxAmount;
    }

    public void setNotTaxAmount(BigDecimal notTaxAmount) {
        this.notTaxAmount = notTaxAmount;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }

    public BigDecimal getBeforeChangeNum() {
        return beforeChangeNum;
    }

    public void setBeforeChangeNum(BigDecimal beforeChangeNum) {
        this.beforeChangeNum = beforeChangeNum;
    }

    public BigDecimal getBeforeChangePrice() {
        return beforeChangePrice;
    }

    public void setBeforeChangePrice(BigDecimal beforeChangePrice) {
        this.beforeChangePrice = beforeChangePrice;
    }

    public BigDecimal getBeforeChangeRate() {
        return beforeChangeRate;
    }

    public void setBeforeChangeRate(BigDecimal beforeChangeRate) {
        this.beforeChangeRate = beforeChangeRate;
    }

    public String getChangeType() {
        return changeType;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
}

==> ejc-proequipmentcorp-impl-3.0.0-20230525.035006-412-sources.jar: com/ejianc/business/proequipmentcorppur/purchase/bean/ChangePurchaseContractOtherDetailedEntity.java <==
package com.ejianc.business.proequipmentcorppur.purchase.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 设备采购合同-变更表-其他费用明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_purchase_change_other_detailed")
public class ChangePurchaseContractOtherDetailedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="tree_index")
    private String treeIndex; // 序号
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 费用项
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="tax_price")
    private BigDecimal taxPrice; // 含税单价
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="amount")
    private BigDecimal amount; // 金额
    @TableField(value="not_tax_price")
    private BigDecimal notTaxPrice; // 单价(无税)
    @TableField(value="not_tax_amount")
    private BigDecimal notTaxAmount; // 金额(无税)
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 税额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="change_id")
    private Long changeId; // 变更id
    @TableField(value="src_tbl_id")
    private Long srcTblId; // 来源子表主键
    @TableField(value="before_change_num")
    private BigDecimal beforeChangeNum;// 变更前数量
    @TableField(value="before_change_price")
    private BigDecimal beforeChangePrice;// 变更前单价(无税)
    @TableField(value="before_change_rate")
    private BigDecimal beforeChangeRate;// 变更前税率
    @TableField(value="change_type")
    private String changeType;// 变更类型
    @TableField(value="contrast_flag")
    private Boolean contrastFlag; // 是否合同带入单据

    public Boolean getContrastFlag() {
        return contrastFlag;
    }

    public void setContrastFlag(Boolean contrastFlag) {
        this.contrastFlag = contrastFlag;
    }

    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }
    public BigDecimal getNotTaxPrice() {
        return notTaxPrice;
    }

    public void setNotTaxPrice(BigDecimal notTaxPrice) {
        this.notTaxPrice = notTaxPrice;
    }
    public BigDecimal getNotTaxAmount() {
        return notTaxAmount;
    }

    public void setNotTaxAmount(BigDecimal notTaxAmount) {
        this.notTaxAmount = notTaxAmount;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }

    public BigDecimal getBeforeChangeNum() {
        return beforeChangeNum;
    }

    public void setBeforeChangeNum(BigDecimal beforeChangeNum) {
        this.beforeChangeNum = beforeChangeNum;
    }

    public BigDecimal getBeforeChangePrice() {
        return beforeChangePrice;
    }

    public void setBeforeChangePrice(BigDecimal beforeChangePrice) {
        this.beforeChangePrice = beforeChangePrice;
    }

    public BigDecimal getBeforeChangeRate() {
        return beforeChangeRate;
    }

    public void setBeforeChangeRate(BigDecimal beforeChangeRate) {
        this.beforeChangeRate = beforeChangeRate;
    }

    public String getChangeType() {
        return changeType;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
}
